"use strict";

const path = require('path');

const HtmlWebpackPlugin = require('html-webpack-plugin');
const CopyPlugin = require("copy-webpack-plugin");

let charting_samples = ['AreaChart', 'BarChart', 'BarChart3D', 'BubbleChart', 'CandlestickChart', 'CustomData', 'Dashboard', 'DateTimeSeries', 'DateTimeSeriesTooltips', 'FunnelChart',
	'GroupLabels', 'Interactivity', 'LineChart', 'ListBinding', 'MultipleAxes', 'MultiplePlots', 'PieChart', 'RadarChart', 'SynchronizedScroll', 'Tutorial1'];
let gauges_samples = ['CarGauges', 'Clock', 'Compass', 'Equalizer', 'Functions', 'Thermometer']
let mainEntry = {
	main: './src/index.ts',
	scripts: './src/samples.ts',
	styles: './src/samples.css'
};
charting_samples.map(name => {
	mainEntry[name] = `./src/${name}.ts`;
});
gauges_samples.map(name => {
	mainEntry[name] = `./src/${name}.ts`;
});

let charting_plugins = charting_samples.map(name => {
	return new HtmlWebpackPlugin({
		template: `./src/${name}.html`,
		filename: `${name}.html`,
		chunks: [`${name}`, 'styles', 'scripts']
	})
});
let gauges_plugins = gauges_samples.map(name => {
	return new HtmlWebpackPlugin({
		template: `./src/${name}.html`,
		filename: `${name}.html`,
		chunks: [`${name}`, 'styles', 'scripts']
	})
});

module.exports = {
	entry: mainEntry,
	output: {
		filename: '[name].js',
		chunkFilename: 'vendor.js',
		path: path.resolve(__dirname, 'dist')
	},
	resolve: {
		extensions: ['.tsx', '.ts', '.js', '.html']
	},
	module: {
		rules: [
			{
				test: /\.tsx?$/,
				use: 'ts-loader',
				exclude: /node_modules/
			},
			{
				test: /\.css$/i,
				use: ["style-loader", "css-loader"],
			},
			{
				test: /\.(png|svg|jpg|jpeg|gif)$/i,
				dependency: { not: ['url'] },
				type: 'asset/resource',
			},
			{
				test: /\.txt/,
				type: 'asset'
			},
			{
				test: /\.xml$/i,
				use: ['xml-loader'],
			}
		]
	},
	plugins: [
		new HtmlWebpackPlugin({
			template: './src/index.html',
			chunks: ['index', 'styles']
		}),
		new CopyPlugin({
			patterns: [
				{ from: './src/data', to: './data', noErrorOnMissing: true },
				{ from: './src/assets/bgimage.png', to: './' },
				{ from: './src/assets/DefaultExt.xml', to: './' },
				{ from: './src/chart_lic.txt', to: './' }
			],
		})
	].concat(charting_plugins).concat(gauges_plugins),
	optimization: {
		runtimeChunk: 'single',
		splitChunks: {
			chunks: 'all'
		}
	},
	mode: 'development',
	devtool: 'source-map'
};